#
# spec file for package emacs-auctex
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with     tex4auto
%define tlversion 2024
%if %{undefined ext_el}
%define ext_el  .gz
%endif

Name:           emacs-auctex
Obsoletes:      ge_auc
Provides:       auc-tex
Provides:       auctex
Provides:       ge_auc
Requires:       emacs
Requires:       texlive-latex
Requires:       texlive-tools
Requires:       emacs(ELPA)
Recommends:     texlive-preview
Supplements:    (texlive and emacs)
BuildRequires:  emacs-x11
BuildRequires:  makeinfo
BuildRequires:  texinfo
%if %{with tex4auto}
BuildRequires:  ghostscript_any
BuildRequires:  texlive >= %tlversion
BuildRequires:  texlive-collection-latexextra >= %tlversion
BuildRequires:  texlive-latex >= %tlversion
BuildRequires:  texlive-tex >= %tlversion
BuildRequires:  texlive-texinfo >= %tlversion
%endif
Version:        14.0.7
Release:        2.2
Summary:        AUC TeX: An Emacs Extension
License:        GPL-3.0-or-later
Group:          Productivity/Editors/Emacs
Source0:        https://elpa.gnu.org/packages/auctex-%{version}.tar
Source1:        https://elpa.gnu.org/packages/auctex-%{version}.tar.sig
Source2:        auctex.keyring
Source3:        auctex-%{version}-auto-TL-%{tlversion}.tar.xz
Source4:        emacs-auctex-rpmlintrc
URL:            https://www.gnu.org/software/auctex
# Allows to select printer instance
# PATCH-FEATURE-UPSTREAM dvips.patch
Patch0:         dvips.patch
BuildArch:      noarch

%description
These macros make it easier for you to write TeX documents with GNU
Emacs.	Documentation can be found under:

/usr/share/doc/packages/emacs-auctex/

and in the dvi files math-ref.dvi and tex-ref.dvi (reference cards) and
in the info file auctex in emacs info-mode.

%define _sitedir %{_datadir}/emacs/site-lisp/elpa
%define _aucdir  %{_sitedir}/auctex-%{version}
%define _smp_mflags -j1

%prep
%setup -n auctex-%{version}
%patch -P0

%build
    unset ${!LC_*}
    LANG=en_US.UTF-8
    export LANG
    EMACS_INHIBIT_AUTOMATIC_NATIVE_COMPILATION=t
    export EMACS_INHIBIT_AUTOMATIC_NATIVE_COMPILATION
    emacs -batch -Q -l package -L ${PWD} \
        --eval "(setq package-user-dir \"/nonexistent\")" \
        --eval "(add-to-list 'package-directory-list \"${PWD}\")" \
         -f package-initialize -f batch-byte-compile *.el style/*.el
    mkdir ${PWD}/auto
%if %{with tex4auto}
    ignore="$(sed -rn '/^\(defcustom TeX-ignore-file/,+1{ s@^\s+@@;s@(\\\\)(\)\$)@\1|lwarp\\.sty\\\\\2@p }' < tex.el)"
    emacs -batch -Q -L ${PWD} \
	--eval "(setq TeX-lisp-directory \"${PWD}\")" \
	--eval "(setq TeX-install-font-lock #'ignore)" \
	--eval "(setq TeX-ignore-file ${ignore})" \
	--eval "(setq TeX-auto-global \"${PWD}/auto\")" \
	-l tex-site -l tex -l latex -l plain-tex -f TeX-auto-generate-global
%else
    TLVERSION=$(rpm -q --qf '%%{VERSION}' -f /etc/texmf)
    if test %{tlversion} -eq ${TLVERSION%%%%.*}
    then
	tar --use-compress-program=xz -xf %{S:3} -C ${PWD}/auto/
    else
	echo Rerun with %%bcond_without tex4auto to generate new
	echo auctex-%{version}-auto-TL-${TLVERSION%%%%.*}.tar.xz
	exit 1
    fi
%endif
    # Otherwise, e.g. the auto/url.el masks out the url/url.el from emacs lisp collections
    for dir in style auto
    do
        test -e ${dir}/.nosearch && continue
        echo ';; AUCTeX style/ and auto/ directories should not appear in load path.' > ${dir}/.nosearch
    done

    # This is part of the (recommended) texlive-preview
    rm -rvf latex/

    unset HOME
    emacs -batch -Q -l package \
	--eval '(setq package-user-dir "/nonexistent")' \
	--eval "(package-generate-autoloads \"auctex\" \"$(cwd)\")"

    pushd doc
%global info_files auctex.info preview-latex.info
        rm -vf *.info *.pdf
	texi2pdf -E auctex.texi
        pdftex tex-ref.tex
	makeinfo -I . auctex.texi
	makeinfo -I . preview-latex.texi
    popd

%install
    unset ${!LC_*}
    LANG=en_US.UTF-8
    export LANG
    EMACS_INHIBIT_AUTOMATIC_NATIVE_COMPILATION=t
    export EMACS_INHIBIT_AUTOMATIC_NATIVE_COMPILATION

unelc ()
{
    local elc=$1
    local elz=${elc%%.elc}.el.gz
    rm -vf $elc
    if test -n "$elz" -a -e "$elz" ; then
	gunzip "$elz"
    fi
}

    mkdir -p %{buildroot}%{_sitedir}/auctex-%{version}
    tar cpf - *.el *.elc auto/ style/ images/ | \
    tar xpf - -C %{buildroot}%{_sitedir}/auctex-%{version}/

    pushd doc
	install -m 644 -D -t %{buildroot}%{_infodir} preview-latex.info
	install -m 644 -D -t %{buildroot}%{_infodir} auctex.info*
    popd

    pushd %{buildroot}%{_sitedir}/auctex-%{version}
	find -name '*.el' -exec gzip -n -f9 '{}' \+
	unelc auctex-autoloads.elc
	unelc auctex-pkg.elc
	unelc auctex.elc
	unelc tex-site.elc
	unelc font-latex.elc
	# Workaround for old stuff in ~/.gnu-emacs which is about loading "auctex/font-latex"
	# in after-init-hook for existing AUCTeX version
	mkdir auctex
	pushd auctex
	    ln -sf ../font-latex.el .
	    echo ';; AUCTeX style/ and auto/ directories should not appear in load path.' > .nosearch
	popd
    popd

%triggerin -- emacs-nox
EMACS_INHIBIT_AUTOMATIC_NATIVE_COMPILATION=t
export EMACS_INHIBIT_AUTOMATIC_NATIVE_COMPILATION
if test -e %{_aucdir}/font-latex.el
then
  owd=$(pwd)
  cd %{_aucdir} || exit 0
  emacs -batch -Q --eval '(setq load-path (cons "." load-path)
    byte-compile-warnings nil
    TeX-lisp-directory "%{_aucdir}"
    TeX-auto-global "%{_aucdir}/auto")' -f batch-byte-compile font-latex.el > /dev/null 2>&1
  cd auctex
  ln -sf ../font-latex.elc .
  cd $owd
fi

%triggerin -- emacs-x11
EMACS_INHIBIT_AUTOMATIC_NATIVE_COMPILATION=t
export EMACS_INHIBIT_AUTOMATIC_NATIVE_COMPILATION
if test -e %{_aucdir}/font-latex.el
then
  owd=$(pwd)
  cd %{_aucdir} || exit 0
  emacs -batch -Q --eval '(setq load-path (cons "." load-path)
    byte-compile-warnings nil
    TeX-lisp-directory "%{_aucdir}"
    TeX-auto-global "%{_aucdir}/auto")' -f batch-byte-compile font-latex.el > /dev/null 2>&1
  cd auctex
  ln -sf ../font-latex.elc .
  cd $owd
fi

%post
for f in %info_files; do
 %install_info --info-dir=%{_infodir} %{_infodir}/$f.gz
done

%postun
for f in %info_files; do
  %install_info_delete --info-dir=%{_infodir} %{_infodir}/$f.gz
done

%files
%defattr(-, root, root)
%license COPYING
%doc README doc/*.pdf ChangeLog
%dir %{_sitedir}/
%dir %{_aucdir}/
%dir %{_aucdir}/auctex/
%dir %{_aucdir}/auto/
%dir %{_aucdir}/images/
%dir %{_aucdir}/style/
%doc %{_infodir}/*.info*.gz
%{_aucdir}/*.el
%{_aucdir}/*.el%{ext_el}
%ghost %verify(not mode) %{_aucdir}/font-latex.elc
%{_aucdir}/*.elc
%{_aucdir}/auctex/font-latex.el
%ghost %verify(not mode) %{_aucdir}/auctex/font-latex.elc
%{_aucdir}/auctex/.nosearch
%{_aucdir}/auto/*.el%{ext_el}
%{_aucdir}/auto/*.elc
%{_aucdir}/auto/.nosearch
%{_aucdir}/images/*.xbm
%{_aucdir}/images/*.xpm
%{_aucdir}/style/*.el%{ext_el}
%{_aucdir}/style/*.elc
%{_aucdir}/style/.nosearch

%changelog
* Thu Nov 21 2024 Bernhard Wiedemann <bwiedemann@suse.com>
- Use gzip -n for deterministic gzip headers
* Tue Nov 19 2024 Dr. Werner Fink <werner@suse.de>
- Update to AUCTeX ELPA version 14.0.7 (2024-10-05)
  * * Added
  - Respect the value of ~TeX-output-dir~ when processing files with
    latexmk.  This means that the default value of ~TeX-command-list~ is
    changed.
  - Add new support files =style/authblk.el=, =style/langscibook.cls=,
    =style/lstautogobble.el=, =style/lstlinebgrd.el=,
    =style/ninecolors.el=, =style/supertabular.el=, =style/tabularray.el=
    and =style/xtab.el=.
  * * Fixed
  - Fold argument of verbatim macros more accurately.
  * * Removed
  - Remove the possibility to disable the side-wide installation with:
    [#]+begin_src emacs-lisp
    (unload-feature 'tex-site)
    [#]+end_src
    Using this form when installed from [[ELPA:auctex.html][ELPA]] will
    throw an error.
* Wed Jul 10 2024 Dr. Werner Fink <werner@suse.de>
- Update to AUCTeX ELPA version 14.0.6
  * This work only with GNU Emacs 27.1 and above
- Remove patches upstream now
  * dinbrief.patch
  * initial-reset.patch
  * auctex-13.1-expand.patch
- Port patch dvips.patch
- Port spec file to ELPA installation with the
  help of triggerin scriptlets
- REcommend texlive-preview as this also from AUCTeX
* Thu May 16 2024 Dr. Werner Fink <werner@suse.de>
- Merge changes from upstream for patch dinbrief.patch
* Thu May 16 2024 Dr. Werner Fink <werner@suse.de>
- Update dinbrief.patch
  * Use babel style direct for ngerman
  * Reintroduce enforced T1 font encoding
* Thu May 16 2024 Dr. Werner Fink <werner@suse.de>
- Remove patch ignore-errors.patch
  * After discussion with AUCTeX upstream avoid now those errors
    by ignoring font-lock TeX macros as well as lwarp.sty
- Refresh auctex-13.3-auto-TL-2024.tar.xz with that above
* Tue May  7 2024 Dr. Werner Fink <werner@suse.de>
- Add patch dinbrief.patch
  * Modernize this class to use by e.g. default UTF-8
- Add patch initial-reset.patch
  (Re)enable initial buffer reset at creation time of the
  document class
* Wed Mar 27 2024 Dr. Werner Fink <werner@suse.de>
- Add patch ignore-errors.patch
  * Allow to scan *all* style files
- Refresh auctex-13.3-auto-TL-2024.tar.xz
* Tue Mar 26 2024 Dr. Werner Fink <werner@suse.de>
- Generate auctex-13.3-auto-TL-2024.tar.xz for TeXLive 2024
* Fri Feb  9 2024 Dr. Werner Fink <werner@suse.de>
- Update to 13.4
  * AUCTeX now requires GNU Emacs 26.1 or higher.
  * LaTeX abbrevs are now available in docTeX mode buffers.
  * AUCTeX temporarily rebinds the variable ‘gc-cons-percentage’ to a
    higher value during parsing which speeds up the process
    significantly.  The memory pressure should still be acceptable,
    even on older machines.
  * Macros provided by the ‘xparse’ package are part of LaTeX kernel
    since October 2020.  AUCTeX tracks this change and the content of
    ‘xparse.el’ is moved into ‘latex.el’ and ‘font-latex.el’
    respectively.
  * The variable ‘preview-scale-function’ is now allowed as a
    file-local variable where the assigned value can only be between
    0.1 and 10.
* Thu Aug  3 2023 Dr. Werner Fink <werner@suse.de>
- Run TeX-auto-generate-global in emacs only once if auctex or
  TeXLive becomes updated to generate all auto lisp files.
* Wed Aug  2 2023 Dr. Werner Fink <werner@suse.de>
- Update to 13.2
  * AUCTeX no longer refuses to insert dollar sign when you type ‘$’ at
    point where AUCTeX thinks the current math mode didn’t start with
    dollar(s).  AUCTeX assumes the user knows that it isn’t in math
    mode actually.
    You can keep the former behavior by enabling the new customize
    option ‘TeX-refuse-unmatched-dollar’.
  * AUCTeX supports completion-at-point of macro and environment
    arguments in LaTeX buffers.  The responsible function recognizes
    the argument position and extracts the corresponding candidates
    from the variables ‘TeX-symbol-list’ and ‘LaTeX-environment-list’.
  * AUCTeX underlines the argument of macros which produce underlined
    text in the final product with ‘font-latex-underline-face’.  The
    corresponding keyword class is called ‘underline-command’.  See the
    section for fontification of macros if you dislike this feature and
    wish to deactivate it.
  * Support for the Sioyek document viewer is added.
  * AUCTeX now requires GNU Emacs 25.1 or higher.
  * AUCTeX tracks the change in Emacs where initial inputs in the
    minibuffer during queries are getting phased out.  Queries for the
    mandatory arguments of macros and environments are adjusted where
    applicable.  The value which will be used after hitting ‘RET’
    without other input is shown in the prompt in parentheses prefixed
    with ‘default’.  For this change the signature of the function
    ‘TeX-arg-length’ is altered.  The old argument list was:
    (defun TeX-arg-length (optional &optional prompt
    initial-input definition default)
    whereas the new one is:
    (defun TeX-arg-length (optional &optional prompt
    default initial-input definition)
    Note the position change of ‘DEFAULT’.
  * Indenting of conditionals is improved.  Code inside constructs like
    ‘\ifx . \else . \fi’ is correctly indented.  An interface for style
    files is also introduced which can add their macros to the
    indentation engine.  Check the file ‘algpseudocode.el’ for an
    example.
  * You can optionally enable indent inside square brackets ‘[]’ by new
    user options ‘TeX-indent-open-delimiters’ and
    ‘TeX-indent-close-delimiters’.
  * Now ‘tex-buf.el’ is merged into ‘tex.el’ and no longer exists.  If
    your personal code has ‘(require 'tex-buf)’, one of the following
    prescriptions would serve.
    1. Remove ‘(require 'tex-buf)’.
    2. Replace it with ‘(require 'tex)’.
    3. Replace it with ‘(require 'latex)’.
  * When you edit a document divided into multiple files, auto parsed
    information for all sub files are saved under ‘auto’ subdirectory
    at master directory when ‘TeX-parse-self’ and ‘TeX-auto-save’
    options are enabled.  Now you can have support ‘.el’ file saved
    under ‘auto’ subdirectory of each directory of the sub file when
    the sub files aren’t located at the master directory.
    To achieve that, set new user option ‘TeX-auto-save-aggregate’ to
    ‘nil’.
  * There was another hook where former dynamic free variables could be
    used.  The usage was invalidated at version 13.1, by introduction
    of lexical binding over AUCTeX.
    The functions in ‘TeX-region-hook’ could access the free variables
    ‘master-buffer’ and ‘orig-buffer’.  Those are now named
    ‘TeX-region-master-buffer’ and ‘TeX-region-orig-buffer’,
    respectively.
* Thu Apr 13 2023 Dr. Werner Fink <werner@suse.de>
- Add patch auctex-13.1-expand.patch
  * Let it build with latest texinfo and TeXLive
- Add keyring
* Mon Sep 12 2022 Dr. Werner Fink <werner@suse.de>
- Update to 13.1
  * In math environments 'gather', 'gather*', 'gathered', 'multline'
    and 'multline*', fill commands such as 'M-q' and 'C-c C-q C-e' are
    disabled.  This sorts out the inconsistency between those and
    'equation', 'displaymath' environments, in latter of which filling
    is already disabled.
    If you want filling in such environments, customize
    'LaTeX-indent-environment-list' to remove them.
    Auto fill continues to work in such environment anyway.
    In addition, AUCTeX adds support of alignment at '&' sign in
    'align'-like environments such as 'alignat', 'aligned' and so on,
    as well as 'matrix'-like environments such as 'pmatrix', 'bmatrix'
    and so on.
  * Now two commands 'Texindex' and 'Texi2dvi' are available when you
    type 'C-c C-c' in Texinfo mode.  The command 'Texindex' runs
    'texindex' on index files and 'Texi2dvi' runs 'pdftexi2dvi' or
    'texi2dvi' according to the value of 'TeX-PDF-mode'.
    So you can typeset Texinfo documents into PDF or DVI format from
    within AUCTeX.
  * AUCTeX's own help messages for LaTeX errors are now shown only for
    LaTeX runs.  AUCTeX shows raw error/warning messages found in
    '.log' files for runs of formats other than LaTeX, such as plain
    TeX, ConTeXt and Texinfo, as it does even for LaTeX runs when it
    can't find a matching entry in its own help message catalogue.
    Due to this change, customize option 'TeX-error-description-list'
    can no longer have a fallback entry that matches any error.  If
    your customized value includes such entry, typically '(".*" . "No
    help available")', please remove it.
  * Two functions 'TeX-split-string' and 'TeX-assoc' are now obsolete
    and will be removed in future release.  If your personal code uses
    these functions, use 'split-string' and 'assoc-string' instead.
  * The function 'TeX-read-key-val' now accepts a function call as
    second argument.  This change should help AUCTeX style writers who
    use 'TeX-arg-key-val' and have to deal with dynamic key-values.
    Example of usage:
    (TeX-add-style-hook "foo"
    (lambda ()
    (TeX-add-symbols
    '("bar" (TeX-arg-key-val (function-returning-key-val))))))
  * Since AUCTeX 12.2, 'C-x C-w' accidentally disabled the parse on
    save in that buffer, even when you enabled 'TeX-auto-save' option.
    This bug was fixed.
  * AUCTeX now requires GNU Emacs 24.3 or higher.
  +
  * Old implementations for viewers were discarded, as announced long
    before.  The variables 'TeX-output-view-style' and 'TeX-view-style'
    have no effect now.  The former placeholders '%%v' and '%%vv' in
    'TeX-command-list' are ignored.
  * AUCTeX now uses lexical binding which has been introduced in Emacs
    24.  This change should have no user-visible effect and require no
    manual adaptions except in the following cases.
  - Entries added to the customization variable 'TeX-expand-list'
    also had access to variables 'command' and 'pos'.  Those are
    now properly declared and named 'TeX-expand-command' and
    'TeX-expand-pos'.
  - Entries added to the customization variable 'TeX-expand-list'
    had access to a variable 'file' which was bound to
    'TeX-active-master', i.e., it evaluated to either the master
    or region file.  This usage must be replaced with either
    'TeX-active-master' or 'TeX-active-master-with-quotes'.
  - Viewer entries in 'TeX-view-program-list' also had access to a
    variable 'file' which was bound to the name of the master or
    region file without extension.  Instead, the function
    'TeX-active-master' has to be used now.
  - Macro argument parsing functions could set a variable
    'exit-mark' to the buffer position where point should be left
    after all arguments have been read.  This variable is now
    named 'TeX-exit-mark'.
  - The functions in 'LaTeX-section-hook' had access or modified
    the previously undeclared variables 'title', 'name', 'level',
    'done-mark', and 'toc'.  These variables are now properly
    declared and have the 'LaTeX-' prefix, e.g.,
    'LaTeX-done-mark'.
  - The functions in 'ConTeXt-numbered-section-hook' and
    'ConTeXt-unnumbered-section-hook' had access or modified the
    previously undeclared variables 'title', 'name', 'level',
    'done-mark', and 'reference'.  These variables are now
    properly declared and have the 'ConTeXt-' prefix, e.g.,
    'ConTeXt-title'.
  - The functions in 'TeX-translate-location-hook' could access
    and modify the free variables 'file', 'line', 'error',
    'offset', 'context', and 'string'.  Those are now properly
    declared variables with the prefix 'TeX-translate-location-',
    e.g., 'TeX-translate-location-file'.
  * The constant 'LaTeX-dialect' has been renamed to 'TeX-dialect' and
    moved from 'latex.el' to 'tex.el'.  'LaTeX-dialect' now is an
    obsolete alias.
  * The style 'latexinfo.el' is removed from AUCTeX.  'latexinfo.el'
    was meant to support latexinfo which in return was a LaTeX-2.09
    extension of Texinfo, but didn't manage to replace Texinfo.
  * The style 'siunitx.el' is updated to support package version 3.
    Key-value options provided by older package versions are removed,
    deprecated macros and units are not supported anymore.
  * AUCTeX has preliminary support for LaTeX-hooks.  Hooks provided by
    LaTeX kernel are known and available for completion in
    '\AddToHook', '\RemoveFromHook' and '\AddToHookNext'.
  * AUCTeX is now able to place all generated output files, including
    those that are produced by applications running under AUCTeX,
    temporary files related to region processing and preview-latex
    files, in an output directory.  To use this feature, set the new
    user option 'TeX-output-dir' to the absolute path of the output
    directory or a relative path which would be interpreted as being
    relative to the master file in a multifile document.
    Note that this feature doesn't work if the document includes sub
    file placed in sub directory below the main file via '\include'
    command.
  * Many other bugs were fixed.
- Port patch dvips.patch
* Thu Oct 14 2021 Dr. Werner Fink <werner@suse.de>
- Update to 12.3
  * Support for 'PSTricks' is now PDF-oriented.  AUCTeX no longer turns
    off PDF mode for 'PSTricks' documents even without 'pst-pdf'.  It
    now sets up 'TeX-PDF-from-DVI' option so that PDF output is
    generated when 'TeX-PDF-mode' is enabled (default).  Users who want
    DVI output should disable PDF mode explicitly by file local
    variable, or customize 'TeX-PDF-mode' to 'nil'.
  * The function 'font-latex-update-font-lock' has been obsoleted in
    order to fix 'bug#37945'.  That function was used by several style
    files in order to refresh fontification after adding new symbols or
    verbatim constructs.  It is better to call 'font-lock-flush' in the
    former case and 'font-latex-set-syntactic-keywords' in the latter
    case.  The function 'font-latex-update-font-lock' still exists as a
    no-op which only shows a warning explaining how to update font-lock
    as mentioned above.
  * Math expression highlighting was improved.  Highlighting for
    documents with a lot of inline math expressions '$...$' won't get
    scrambled now ('bug#33139').
  * AUCTeX tracks changes in LaTeX2e 2020-02-02 release.  AUCTeX
    supports the improvements to LaTeX font selection mechanism (NFSS).
    New macros like '\textsw' or '\textulc' are added to font insertion
    keyboard commands.  See the section for inserting font specifiers
    for details.  Further, the entries in the menu LaTeX, Insert Font
    are reorganized and adjusted accordingly.
  * Insertion of environments in LaTeX documents (i.e.  'C-c C-e') was
    improved.  The former code had a few bugs, which sometimes resulted
    in either spurious empty line or spurious comment prefix, or both,
    especially when the region is active.  Those bugs are now fixed.
  * More bugs fixed, other minor features implemented.
* Fri Aug 14 2020 Dr. Werner Fink <werner@suse.de>
- Update to 12.2 to avoid obsolete (process-kill-without-query) (boo#1175274)
  * AUCTeX reflects the changes in LaTeX2e 2019-10-01 release.
    'filecontents' environment now takes an optional argument and can
    be used anywhere in a document.  The macros '\Ref' and
    '\labelformat' are moved from 'varioref.sty' to LaTeX kernel.
    amsmath has a new macro '\overunderset'.
  * A new method is implemented in preview-latex to adjust the
    foreground colors of generated images to those of Emacs, when the
    LaTeX command produces PDF.  The traditional method became invalid
    because of the change introduced in Ghostscript 9.27.
    Unfortunately, the new method doesn't work due to a bug in
    Ghostscript 9.27 and is valid only for Ghostscript > 9.27.  There
    is also a fallback method for gs 9.27 users which displays plain
    "black on white" images.  For successful function of preview-latex,
    the users are encouraged to set up the new user option
    'preview-pdf-color-adjust-method' to choose appropriate option
    among the three: new, traditional and fallback method.
  * AUCTeX has support for the Flymake package in Emacs 26 or newer.
    To enable, call 'M-x flymake-mode RET' or add this to your '.emacs'
    file:
    (add-hook 'LaTeX-mode-hook #'flymake-mode)
  * The way the option 'TeX-record-buffer' is used was corrected.  It
    was used in just the opposite way as the document says.  Erase the
    customization if you have customized this option since it now acts
    in reverse to your expectation.
  * A former customize option 'japanese-TeX-command-list' is removed.
    Use 'japanese-TeX-engine-default', or if it's really necessary,
    customize 'TeX-command-list' directly if the task which the option
    used to carry is required.
  * Support for standard LaTeX without e-TeX extension is now very
    limited.  It doesn't work if raw TeX code is put on the command
    line to invoke latex command.  It also fails for region compilation
    ('C-c C-r' and so on) with documents of non-ascii file name.  In
    addition, it no longer works with preview-latex.  We consider this
    incompatibility is permissible because e-TeX extension is enabled
    for standard LaTeX by default long ago.  LaTeX variants such as
    XeLaTeX and LuaLaTeX are not affected.
  * Key binds in Texinfo mode are improved.  Typing '$', '^', '_' and
    '\' now just self-inserts without pointless side effects in Texinfo
    mode.
    In addition, the option 'TeX-electric-escape' is now effective in
    Texinfo mode.  When it is enabled, typing '@' will invoke
    'TeX-electric-macro' offering completion in similar style with
    other TeX modes of AUCTeX.
  * Fontification support for 'biblatex' package is improved and
    updated to macros provided by package version 3.12.  For qualified
    lists, at least 2 mandatory arguments are fontified.
  * Support for column specifiers 'w' and 'W' provided by 'array'
    package is added to 'array.el'.  The correct counting of columns
    only works when the 'align' parameter is enclosed in braces, e.g.,
    'w{l}{3cm}'.  The short version 'wl{3cm}' is not supported.
  * Entries for 'PDF Tools' are added in
    'TeX-view-program-list-builtin' for Windows and macOS. This viewer
    can be configured under these operating systems with an entry like
    this in an init file:
    (setq TeX-view-program-selection '((output-pdf "PDF Tools")))
  * Several other bugs were fixed, many minor features were added.
- Drop patches which seem now obsolete
  * utf8-names-3b1ffcd8.patch
  * utf8-names-a8ea1273.patch
  * utf8-names-fix-boo1135326.patch
- Correct line number in patch dvips.patch
* Tue Dec  3 2019 Dr. Werner Fink <werner@suse.de>
- Supplement emacs-auctex if texlive and emacs are installed (boo#1158035)
* Fri Jun 21 2019 Dr. Werner Fink <werner@suse.de>
- Fix the two last upstream commits by adding patch
  utf8-names-fix-boo1135326.patch which is kind of a backport for
  bug boo#1135326
* Wed Jul 25 2018 werner@suse.de
- Add patches/commits from upstream utf8-names-3b1ffcd8.patch and
  utf8-names-a8ea1273.patch to be able handle files names with
  UTF-8 characters as well
* Wed Apr 18 2018 werner@suse.de
- Update to 12.1 due bug boo#1088548
  * AUCTeX now requires GNU Emacs 24 or higher.  Support for XEmacs has
  * Besides the change in the supported version of Emacs, there has
    been no functional change in this release, which is equivalent to
    version 11.92.
  * preview-latex is compatible with Ghostscript 9.22 where the
    operator '.runandhide' is removed.  All occurrences of
    '.runandhide' in preview-latex are replaced by alternative code
    making it work with Ghostscript 9.22 again.
  * AUCTeX has a new customize option
    'TeX-math-input-method-off-regexp'.  When you begin to input a math
    formula, the current input method is turned off if its name matches
    this regular expression.
  * The window system focus is pulled back to Emacs when viewing with
    evince-compatible viewers if a new customize option
    'TeX-view-evince-keep-focus' is non-nil.
  * The usual dose of bug fixes was administered.
  * Now AUCTeX has a logo.  The LaTeX code to create it is available in
    the 'etc/' directory of the package.
  * Add support for 'upmendex', an extension of 'makeindex' capable of
    sorting indexes by unicode based ICU.
  * Fix preview-latex to interact correctly with Japanese LaTeX.  The
    parsing routine was made robust not to be confused by the 7-bit
    encoding of Japanese text and the necessary option to LaTeX command
    is kept even when preamble caching is enabled.
  * The new "Glossaries" entry in 'TeX-command-list' runs the command
    'makeglossaries'.
  * Fontification of control symbols has been improved.  Characters
    defined in 'font-latex-match-simple-exclude-list' do not receive
    any fontification.  In DocTeX mode, the character '_' is removed
    from 'font-latex-match-simple-exclude-list' in order to fontify
    macros like '\__module_foo:nnn' correctly.
  * Fontification of math environments has been improved.  Optional
    and/or mandatory argument(s) to environments are not fontified.
  * 'preview.sty' loads 'luatex85.sty' if possible and should be
    compatible with newer luaTeX versions.
  * AUCTeX has a new customize option 'TeX-ispell-verb-delimiters'.
    This string contains usual characters used as delimiters for
    in-line verbatim macros like '\verb'.  Text between delimiters
    after an in-line verbatim macro will be skipped during spell
    checking.
  * Fontification of in-line verbatim macros has been improved.
    'font-latex.el' recognizes an optional or a mandatory argument for
    macros like '\Verb' from 'fancyvrb.sty', '\mint' and '\mintinline'
    from 'minted.sty' and fontifies verbatim content correctly.
  * AUCTeX can put and parse labels in optional argument of
    environments.  Inserting labels is done by new function
    'LaTeX-env-label-as-keyval'.  A new customize option
    'LaTeX-listing-label' is available as prefix to labels in code
    typesetting environments, e.g.  'lstlisting' environment provided
    by 'listings' package.  'LaTeX-listing-label' defaults to 'lst:'.
    Parsing of labels for later referencing relies on two requirements:
    1. Label should come as last key-value argument, and
    2. label must be enclosed in braces, e.g.
    \begin{lstlisting}[caption=Some Caption,label={lst:foo}]
    ...
    \end{lstlisting}
  * The function 'LaTeX-label' now takes a second optional argument
    'NO-INSERT'.  When non-'nil', 'LaTeX-label' reads a label and
    returns it as a string.  This argument is also passed to any
    function bound to 'LaTeX-label-function' (see next item).
  * *Incompatible change:* The signature for the function passed with
    the customize option 'LaTeX-label-function' has changed.  The
    function bound to this variable is now expected to take an optional
    second argument 'NO-INSERT'.  When this argument is non-'nil', the
    function should read and only return a label as a string; insertion
    is done by another function.
  * Directory local variables were ineffective for
    'japanese-latex-mode' and 'japanese-plain-tex-mode'.  This bug was
    fixed.  (This was actually done in AUCTeX 11.90, but not
    advertised)
  * The output of Japanese text from Japanese TeX engines is decoded
    correctly for most cases, according to the encoding of the TeX
    documents and the locale.  The difference between MS Windows, macOS
    and unix-like OS is taken into account.  (This was actually done in
    AUCTeX 11.90, but not advertised)
  * Quite a few new LaTeX packages are supported.
  * As usual, many bugs were fixed.
* Thu Jun 29 2017 werner@suse.de
- Update to 11.90
  * In addition to the completion performed by 'TeX-complete-symbol',
    AUCTeX now also supports the new Emacs standard completion-at-point
    facility (see the Emacs command 'completion-at-point').  This also
    means that modern completion UIs like company-mode work out of the
    box in TeX and LaTeX buffers.
  * Completion is now aware of being inside a math environment and then
    completes math macros.
  * AUCTeX is able to display several levels of super- and subscripts,
    each one raised above and a bit smaller than its basis.  For this
    feature, have a look at the customize options
    'font-latex-fontify-script' (especially the new values
    'multi-level' and 'invisible') and
    'font-latex-fontify-script-max-level'.  Also, the script characters
    '^' and '_' are also fontified with a special face named
    'font-latex-script-char-face'.
  * Parsing of format specification in various tabular environments has
    been improved.  The function 'LaTeX-insert-item' ('C-c <LFD>')
    inserts suitable number of ampersands for '*{num}{cols}'
    constructs.  Style files for LaTeX packages 'tabularx', 'tabulary',
    'longtable', 'dcolumn' and 'siunitx' are adapted to take advantage
    of this improvement.
  * AUCTeX has a new Ispell dictionary 'tex-ispell.el' for macros and
    environments which will be skipped during spell checking.  The
    activiation of this feature is controlled by a new customize option
    'TeX-ispell-extend-skip-list', which is set to 't' and activated by
    default.
  * AUCTeX has a new customize option 'TeX-raise-frame-function' that
    is currently only used by Evince and Atril inverse search to raise
    the Emacs frame.
  * When inserting a new float, AUCTeX will now prompt for a
    short-caption if the length of the caption provided is greater than
    a certain size.  This size is controlled via a new user option
    'LaTeX-short-caption-prompt-length'.
  * Parsing of the compilation log has been reworked.  You should
    encounter fewer mistaken files while navigating through errors and
    warnings.
  * Two new user options, 'TeX-ignore-warnings' and
    'TeX-suppress-ignored-warnings', allow ignoring certain warnings
    after compilation of the document.
  * A new option, 'TeX-PDF-from-DVI', controls if and how to produce a
    PDF file by converting a DVI file.  This supersedes
    'TeX-PDF-via-dvips-ps2pdf' which is still recognized but marked as
    obsolete and may be removed in future releases.
  * Support for a number of external viewers has been added
  * A new function, 'TeX-documentation-texdoc', for reading
    documentation with 'texdoc' has been added.  'TeX-doc' is still
    available but now 'C-c ?' runs 'TeX-documentation-texdoc'.
  * AUCTeX has a new custom option
    'LaTeX-reftex-cite-format-auto-activate' which controls the
    automatic activation of citation formats provided by RefTeX when a
    style file is loaded and RefTeX is enabled.  Currently,
    'biblatex.el', 'harvard.el', 'jurabib.el' and 'natbib.el' use this
    feature.  If you have customized 'reftex-cite-format' and want to
    use your settings, you should set this variable to 'nil'.
  * AUCTeX now has limited support for the TikZ package.  For the
    moment, this includes some basic support for prompting the user of
    arguments to the '\draw' macro.
  * The style 'graphicx.el' went through a bigger overhaul.  The
    optional argument of command '\includegraphics' now supports
    key-val query; keys can independently be chosen anytime by pressing
    the <,> key.  As a side effect, the variable
    'LaTeX-includegraphics-options-alist' is now no-op and is removed
    from 'tex-style.el'.  You can safely remove any customization of it
    from your init file.  The mandatory argument of '\includegraphics'
    knows about image file extensions supported by the used engine and
    offers them for inclusion.
  * Support for other LaTeX packages was improved, and style files for
    several new packages were added.
  * Many bugs were crushed along the way.
- Remove patch 0001-Fix_bug_in_subfigure_style_filee.patch as now upstream
* Tue Sep 20 2016 werner@suse.de
- Add patch 0001-Fix_bug_in_subfigure_style_filee.patch
  to fix build with GNU Emacs 25.1
* Fri Nov 13 2015 auxsvr@gmail.com
- Remove auctex-11.86-dinbrief.dif, as it's been merged upstream, and
  everything in auctex-11.87.dif except for the dvips part (now in
  dvips.patch).
- Update to 18.89.
  * You can now run all commands needed to compile a document and then
    open the viewer with a single command: 'TeX-command-run-all', bound
    to 'C-c C-a'.
  * Commands such as LaTeX and View can now be executed conveniently on
    the current section (or part, chapter, subsection, etc).  See
    'LaTeX-command-section' and 'LaTeX-command-section-change-level'.
  * Forward and backward search with Evince now also work when only a
    region of the document is compiled/viewed.
  * To open the PDF output file you can now use also PDF Tools, a
    document viewer for Emacs.  With it, as a plus, forward and
    backward search is accurate at word level.
  * With new option 'TeX-PDF-via-dvips-ps2pdf' it is possible to
    compile a document to DVI and then convert it to PDF using
    'dvips'-'ps2pdf' before viewing it.
  * New option 'TeX-file-line-error' allows to select file:line:error
    style for error messages.
  * Indent '\[...\]' math mode as a regular environment by default.
  * Now AUCTeX suggests to run 'makeindex' when appropriate.
  * 'TeX-view-program-list' can contain, as third optional element of
    each item, the name of the executable(s) needed to open the viewer.
  * 'TeX-expand-list' variable has been split into 'TeX-expand-list'
    and 'TeX-expand-list-builtin'.  Only the former is intended to be
    customized by the user, the latter contains built-in expanders.
    You might want to keep in 'TeX-expand-list' only new expansion
    strings.
  * When new option 'TeX-check-engine' is non-nil, before running LaTeX
    commands AUCTeX will check whether the correct engine has been set,
    based upon known restrictions posed by LaTeX packages.
  * Basic support to ConTeXt Mark IV has been added.  Users can now
    select the Mark version to be used with new option
    'ConTeXt-Mark-version', and AUCTeX is able to catch error messages
    in the output log of a Mark IV document.
* Sun Sep 13 2015 auxsvr@gmail.com
- Update to 11.88
  * 'TeX-PDF-mode' is now enabled.
  * 'biblatex' support was greatly expanded.  If parsing is enabled, AUCTeX
    looks at 'backend' option to decide whether to use Biber or BibTeX. The
    'LaTeX-biblatex-use-Biber' variable was changed to be file local only
    and is no more customizable.by default.
  * Now you can insert '$...$' or '\(...\)' by typing a single '$'.  To do
    this, customize the new option 'TeX-electric-math'.
    'TeX-math-close-double-dollar' was removed.
  * Brace pairing feature was enhanced in LaTeX documents.  Support for
    '\bigl', '\Bigl', '\biggl' and '\Biggl', the same as the one for
    '\left', was added to 'TeX-insert-macro'.  For example, 'C-c <RET> bigl
    <RET> ( <RET>' inserts '\bigl(\bigr)'.
  * You can insert brace pair '()', '{}' and '[]' by typing a single left
    brace if the new user option 'LaTeX-electric-left-right-brace' is
    enabled.
* Tue Oct  7 2014 crrodriguez@opensuse.org
- No shared libraries are needed for build, this is a noarch
  package.
* Wed Sep 25 2013 werner@suse.de
- Make it build again as we have now a site-start.d below site-lisp
* Fri Jun  7 2013 werner@suse.de
- Use latest upstream update of dinbrief.el
* Thu Jun  6 2013 werner@suse.de
- Update to auctex 11.87
  * Includes the preview fix for ghostscript
  * Includes the changes for font-late.elc
- Remove auctex-11.86-font-latex.5.194.patch
* Thu Jun  6 2013 werner@suse.de
- Add patch auctex-11.86-font-latex.5.194.patch from upstream to
  make GNU emacs 24.3 silent about font-late.elc (reported by
  Johannes Roth)
* Fri Feb 22 2013 werner@suse.de
- Make dinbrief work again
* Mon Jul 23 2012 werner@suse.de
- Use texlive-texinfo for build and add also all LaTeX styles to
  be scanned during AucTeX build.
- Use texinfo *and* makeinfo for build as both are required
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant/obsolete tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Wed Oct 13 2010 werner@suse.de
- Allow also to read PDF file its self to be able to generate the
  descriptions of those file (based on patch of Dieter Jurzitza)
* Wed Aug 11 2010 werner@suse.de
- Make fix for bnc#623719 more flexible
* Sun Jul 25 2010 aj@suse.de
- Package all info files.
* Wed Jul 21 2010 werner@suse.de
- Update to auctex 11.86
  * Parsing of LaTeX output was improved.  It is now less likely that
    AUCTeX opens a non-existent file upon calling `TeX-next-error'; a
    problem for example encountered when using MiKTeX 2.8.  In addition
    quoted file names as emitted by MiKTeX are now supported.
  * A new framework for the definition and selection of viewers was
    implemented.  If you have customizations regarding viewers you
    will have to redo them in this new framework or reenable the old
    one.  See the section on viewers in the manual for details.
  * Comprehensive editing support for PSTricks was added.
  * Support for various LaTeX packages was added, e.g. `tabularx',
    `CJK', and `hyperref'.
  * An easy way to switch between TeX engines (PDFTeX, LuaTeX, XeTeX,
    Omega) was added.
  * Support for SyncTeX was added.  This involves the command line
    options for LaTeX and the viewer.
  * Folding can now be customized to use macro arguments as replacement
    text.
  * `preview.sty' now works with XeTeX.
  * A lot of smaller and larger bugs have been squashed.
* Wed Jul 21 2010 werner@suse.de
- Fix the usage of ghostscript for preview mode also switch over to
  faster dvipng mode which is much faster than ghostscript (bnc#623719)
* Mon Mar 17 2008 werner@suse.de
- Use texlive-tools instead of lacheck
* Tue Mar 11 2008 werner@suse.de
- Avoid overlong file lists use find and xargs instead
* Mon Mar 10 2008 werner@suse.de
- Make it work with texlive and texlive-latex
- Update to auctec 11.85
  + News in 11.85
  * Font locking has been improved significantly.
  * The license was updated to GPLv3.
  * Support for the nomencl, flashcards and comment LaTeX packages
    as well as the Icelandic language option of babel were added.
  * Support for folding of math macros was added.
  * Lots of minor bugs in features and documentation fixed.
  + News in 11.84
  * AUCTeX has been changed in order to accommodate file names
    containing spaces.
  * Support for folding of comments was added.
  * The TeX tool bar is now available and enabled by default in
    plain TeX mode.
  * Bug fix in the display of math subscripts and superscripts.
  * Bug fix `TeX-doc' for Emacs 21.
  * There has been quite a number of other bug fixes to various
    features and documentation across the board.
* Sun Apr 29 2007 aj@suse.de
- Fix Requires for texlive.
* Fri Apr 27 2007 werner@suse.de
- Make it build with texlive
* Fri Mar  2 2007 werner@suse.de
- No binary anymore is no architecture
* Thu Jun 29 2006 werner@suse.de
- Update to 11.83
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Sep 22 2005 werner@suse.de
- Update to 11.55
- Use newer dinbrief.el
- Build as non root user
* Tue Sep 21 2004 werner@suse.de
- encl, cc ... should be included within letter environment
* Fri Jan  9 2004 werner@suse.de
- Update to 11.14
* Tue Jul  2 2002 werner@suse.de
- Update to auc-tex 11.11 (bug #16605)
* Fri Feb 22 2002 werner@suse.de
- Make conditionals in font-lock work with emacs 21.1
* Sat Feb  9 2002 ro@suse.de
- removed te_fr from neededforbuild
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Thu Nov  8 2001 werner@suse.de
- Add all libs reqired by emacs to neededforbuild
* Fri Mar 16 2001 werner@suse.de
- Mark tex-site.el as config file
* Tue Mar 13 2001 ro@suse.de
- added emacs-x11 to neededforbuild
* Wed Mar  7 2001 werner@suse.de
- Rename package to emacs-auctex
* Fri Nov 17 2000 ro@suse.de
- ge_exec -> emacs
* Tue Jun  6 2000 ro@suse.de
- doc relocation
* Fri Feb 25 2000 werner@suse.de
- Change dvips print command to be able to avoid config.lp
  within teTeX package
* Thu Feb 24 2000 werner@suse.de
- Make it work for all teTeX versions
  - /usr/info -> /usr/share/info
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Fri Aug 13 1999 werner@suse.de
- Make dinbrief.sty comaptible to xemacs
* Thu Jul  8 1999 werner@suse.de
- New version 9.9p
  - A few changes to my dinbrief.sty
* Thu Apr 15 1999 werner@suse.de
- added export LC_CTYPE=ISO-8859-1 to install section
* Wed Nov 18 1998 werner@suse.de
- Change file list because of the new tetex version
* Mon Jul 27 1998 bs@suse.de
- added export LC_CTYPE=ISO-8859-1 to build section - emacs needs it.
* Fri Jul 10 1998 bs@suse.de
- added xaw3d to neededforbuild (ge_exec needs it)
* Mon Jun  2 1997 werner@suse.de
- removed /usr/info/latex*.gz ... because it's included in tetex
* Wed May 28 1997 werner@suse.de
- New version 9.7p
  - Skip X-emacs: xemacs-19.15 has an integrated
  auctex version 9.7l
  - Added ltx-help.el, latex(2e).info due
  the auctex-9.7p does not has it anymore
* Thu Jan  2 1997 werner@suse.de
- auctex: Version 9.5a für GNU-emacs und X-emacs
